@@ -1,9 +1,7 @@
-# coding=utf-8
-from __future__ import unicode_literals
-localized = True
-
 from .. import BaseProvider
 
+localized = True
+
 
 class Provider(BaseProvider):
     ssn_formats = ("###-##-####",)
